==========
mangoutils
==========

MOVED PERMANENTLY TO mutils (http://pypi.python.org/pypi/mutils)


Submodules
==========
* web: utility classes for handling urls, list of well known cdns, top level domains
* html: utility class for parsing html and accessing elements via xpath
* system: platform related functions

